@@ -67,7 +67,7 @@ print(__doc__)
 import datetime
 
 import numpy as np
-import pylab as pl
+import matplotlib.pyplot as plt
 from matplotlib import finance
 from matplotlib.collections import LineCollection
 
@@ -78,8 +78,8 @@ from sklearn import cluster, covariance, manifold
 
 # Choose a time period reasonnably calm (not too long ago so that we get
 # high-tech firms, and before the 2008 crash)
-d1 = datetime.datetime(2003, 01, 01)
-d2 = datetime.datetime(2008, 01, 01)
+d1 = datetime.datetime(2003, 1, 1)
+d2 = datetime.datetime(2008, 1, 1)
 
 # kraft symbol has now changed from KFT to MDLZ in yahoo
 symbol_dict = {
@@ -116,7 +116,6 @@ symbol_dict = {
     'MAR': 'Marriott',
     'PG': 'Procter Gamble',
     'CL': 'Colgate-Palmolive',
-    'NWS': 'News Corp',
     'GE': 'General Electrics',
     'WFC': 'Wells Fargo',
     'JPM': 'JPMorgan Chase',
@@ -145,7 +144,7 @@ symbol_dict = {
     'CAT': 'Caterpillar',
     'DD': 'DuPont de Nemours'}
 
-symbols, names = np.array(symbol_dict.items()).T
+symbols, names = np.array(list(symbol_dict.items())).T
 
 quotes = [finance.quotes_historical_yahoo(symbol, d1, d2, asobject=True)
           for symbol in symbols]
@@ -189,10 +188,10 @@ embedding = node_position_model.fit_transform(X.T).T
 
 ###############################################################################
 # Visualization
-pl.figure(1, facecolor='w', figsize=(10, 8))
-pl.clf()
-ax = pl.axes([0., 0., 1., 1.])
-pl.axis('off')
+plt.figure(1, facecolor='w', figsize=(10, 8))
+plt.clf()
+ax = plt.axes([0., 0., 1., 1.])
+plt.axis('off')
 
 # Display a graph of the partial correlations
 partial_correlations = edge_model.precision_.copy()
@@ -202,8 +201,8 @@ partial_correlations *= d[:, np.newaxis]
 non_zero = (np.abs(np.triu(partial_correlations, k=1)) > 0.02)
 
 # Plot the nodes using the coordinates of our embedding
-pl.scatter(embedding[0], embedding[1], s=100 * d ** 2, c=labels,
-           cmap=pl.cm.spectral)
+plt.scatter(embedding[0], embedding[1], s=100 * d ** 2, c=labels,
+            cmap=plt.cm.spectral)
 
 # Plot the edges
 start_idx, end_idx = np.where(non_zero)
@@ -213,8 +212,8 @@ segments = [[embedding[:, start], embedding[:, stop]]
             for start, stop in zip(start_idx, end_idx)]
 values = np.abs(partial_correlations[non_zero])
 lc = LineCollection(segments,
-                    zorder=0, cmap=pl.cm.hot_r,
-                    norm=pl.Normalize(0, .7 * values.max()))
+                    zorder=0, cmap=plt.cm.hot_r,
+                    norm=plt.Normalize(0, .7 * values.max()))
 lc.set_array(values)
 lc.set_linewidths(15 * values)
 ax.add_collection(lc)
@@ -242,16 +241,16 @@ for index, (name, label, (x, y)) in enumerate(
     else:
         verticalalignment = 'top'
         y = y - .002
-    pl.text(x, y, name, size=10,
-            horizontalalignment=horizontalalignment,
-            verticalalignment=verticalalignment,
-            bbox=dict(facecolor='w',
-                      edgecolor=pl.cm.spectral(label / float(n_labels)),
-                      alpha=.6))
+    plt.text(x, y, name, size=10,
+             horizontalalignment=horizontalalignment,
+             verticalalignment=verticalalignment,
+             bbox=dict(facecolor='w',
+                       edgecolor=plt.cm.spectral(label / float(n_labels)),
+                       alpha=.6))
 
-pl.xlim(embedding[0].min() - .15 * embedding[0].ptp(),
-        embedding[0].max() + .10 * embedding[0].ptp(),)
-pl.ylim(embedding[1].min() - .03 * embedding[1].ptp(),
-        embedding[1].max() + .03 * embedding[1].ptp())
+plt.xlim(embedding[0].min() - .15 * embedding[0].ptp(),
+         embedding[0].max() + .10 * embedding[0].ptp(),)
+plt.ylim(embedding[1].min() - .03 * embedding[1].ptp(),
+         embedding[1].max() + .03 * embedding[1].ptp())
 
-pl.show()
+plt.show()
