@@ -18,7 +18,7 @@ LDA, in contrast to PCA, is a supervised method, using known class labels.
 """
 print(__doc__)
 
-import pylab as pl
+import matplotlib.pyplot as plt
 
 from sklearn import datasets
 from sklearn.decomposition import PCA
@@ -40,16 +40,16 @@ X_r2 = lda.fit(X, y).transform(X)
 print('explained variance ratio (first two components): %s'
       % str(pca.explained_variance_ratio_))
 
-pl.figure()
+plt.figure()
 for c, i, target_name in zip("rgb", [0, 1, 2], target_names):
-    pl.scatter(X_r[y == i, 0], X_r[y == i, 1], c=c, label=target_name)
-pl.legend()
-pl.title('PCA of IRIS dataset')
+    plt.scatter(X_r[y == i, 0], X_r[y == i, 1], c=c, label=target_name)
+plt.legend()
+plt.title('PCA of IRIS dataset')
 
-pl.figure()
+plt.figure()
 for c, i, target_name in zip("rgb", [0, 1, 2], target_names):
-    pl.scatter(X_r2[y == i, 0], X_r2[y == i, 1], c=c, label=target_name)
-pl.legend()
-pl.title('LDA of IRIS dataset')
+    plt.scatter(X_r2[y == i, 0], X_r2[y == i, 1], c=c, label=target_name)
+plt.legend()
+plt.title('LDA of IRIS dataset')
 
-pl.show()
+plt.show()
