@@ -14,7 +14,15 @@ detail.
 """
 print(__doc__)
 
+# Author: Noel Dawe <noel.dawe@gmail.com>
+#
+# License: BSD 3 clause
+
+# importing necessary libraries
 import numpy as np
+import matplotlib.pyplot as plt
+from sklearn.tree import DecisionTreeRegressor
+from sklearn.ensemble import AdaBoostRegressor
 
 # Create a the dataset
 rng = np.random.RandomState(1)
@@ -22,9 +30,6 @@ X = np.linspace(0, 6, 100)[:, np.newaxis]
 y = np.sin(X).ravel() + np.sin(6 * X).ravel() + rng.normal(0, 0.1, X.shape[0])
 
 # Fit regression model
-from sklearn.tree import DecisionTreeRegressor
-from sklearn.ensemble import AdaBoostRegressor
-
 clf_1 = DecisionTreeRegressor(max_depth=4)
 
 clf_2 = AdaBoostRegressor(DecisionTreeRegressor(max_depth=4),
@@ -38,14 +43,12 @@ y_1 = clf_1.predict(X)
 y_2 = clf_2.predict(X)
 
 # Plot the results
-import pylab as pl
-
-pl.figure()
-pl.scatter(X, y, c="k", label="training samples")
-pl.plot(X, y_1, c="g", label="n_estimators=1", linewidth=2)
-pl.plot(X, y_2, c="r", label="n_estimators=300", linewidth=2)
-pl.xlabel("data")
-pl.ylabel("target")
-pl.title("Boosted Decision Tree Regression")
-pl.legend()
-pl.show()
+plt.figure()
+plt.scatter(X, y, c="k", label="training samples")
+plt.plot(X, y_1, c="g", label="n_estimators=1", linewidth=2)
+plt.plot(X, y_2, c="r", label="n_estimators=300", linewidth=2)
+plt.xlabel("data")
+plt.ylabel("target")
+plt.title("Boosted Decision Tree Regression")
+plt.legend()
+plt.show()
