@@ -15,7 +15,8 @@ print(__doc__)
 # License: BSD 3 clause
 
 import numpy as np
-import pylab as pl
+import matplotlib.pyplot as plt
+
 from sklearn import ensemble
 from sklearn import datasets
 from sklearn.utils import shuffle
@@ -49,16 +50,16 @@ test_score = np.zeros((params['n_estimators'],), dtype=np.float64)
 for i, y_pred in enumerate(clf.staged_decision_function(X_test)):
     test_score[i] = clf.loss_(y_test, y_pred)
 
-pl.figure(figsize=(12, 6))
-pl.subplot(1, 2, 1)
-pl.title('Deviance')
-pl.plot(np.arange(params['n_estimators']) + 1, clf.train_score_, 'b-',
-        label='Training Set Deviance')
-pl.plot(np.arange(params['n_estimators']) + 1, test_score, 'r-',
-        label='Test Set Deviance')
-pl.legend(loc='upper right')
-pl.xlabel('Boosting Iterations')
-pl.ylabel('Deviance')
+plt.figure(figsize=(12, 6))
+plt.subplot(1, 2, 1)
+plt.title('Deviance')
+plt.plot(np.arange(params['n_estimators']) + 1, clf.train_score_, 'b-',
+         label='Training Set Deviance')
+plt.plot(np.arange(params['n_estimators']) + 1, test_score, 'r-',
+         label='Test Set Deviance')
+plt.legend(loc='upper right')
+plt.xlabel('Boosting Iterations')
+plt.ylabel('Deviance')
 
 ###############################################################################
 # Plot feature importance
@@ -67,9 +68,9 @@ feature_importance = clf.feature_importances_
 feature_importance = 100.0 * (feature_importance / feature_importance.max())
 sorted_idx = np.argsort(feature_importance)
 pos = np.arange(sorted_idx.shape[0]) + .5
-pl.subplot(1, 2, 2)
-pl.barh(pos, feature_importance[sorted_idx], align='center')
-pl.yticks(pos, boston.feature_names[sorted_idx])
-pl.xlabel('Relative Importance')
-pl.title('Variable Importance')
-pl.show()
+plt.subplot(1, 2, 2)
+plt.barh(pos, feature_importance[sorted_idx], align='center')
+plt.yticks(pos, boston.feature_names[sorted_idx])
+plt.xlabel('Relative Importance')
+plt.title('Variable Importance')
+plt.show()
