@@ -16,6 +16,7 @@ print(__doc__)
 from sklearn.svm import SVC
 from sklearn.datasets import load_digits
 from sklearn.feature_selection import RFE
+import matplotlib.pyplot as plt
 
 # Load the digits dataset
 digits = load_digits()
@@ -29,8 +30,7 @@ rfe.fit(X, y)
 ranking = rfe.ranking_.reshape(digits.images[0].shape)
 
 # Plot pixel ranking
-import pylab as pl
-pl.matshow(ranking)
-pl.colorbar()
-pl.title("Ranking of pixels with RFE")
-pl.show()
+plt.matshow(ranking)
+plt.colorbar()
+plt.title("Ranking of pixels with RFE")
+plt.show()
