@@ -12,7 +12,6 @@ from sklearn.svm import SVC
 from sklearn.cross_validation import StratifiedKFold
 from sklearn.feature_selection import RFECV
 from sklearn.datasets import make_classification
-from sklearn.metrics import zero_one_loss
 
 # Build a classification task using 3 informative features
 X, y = make_classification(n_samples=1000, n_features=25, n_informative=3,
@@ -21,6 +20,8 @@ X, y = make_classification(n_samples=1000, n_features=25, n_informative=3,
 
 # Create the RFE object and compute a cross-validated score.
 svc = SVC(kernel="linear")
+# The "accuracy" scoring is proportional to the number of correct
+# classifications
 rfecv = RFECV(estimator=svc, step=1, cv=StratifiedKFold(y, 2),
               scoring='accuracy')
 rfecv.fit(X, y)
@@ -28,9 +29,9 @@ rfecv.fit(X, y)
 print("Optimal number of features : %d" % rfecv.n_features_)
 
 # Plot number of features VS. cross-validation scores
-import pylab as pl
-pl.figure()
-pl.xlabel("Number of features selected")
-pl.ylabel("Cross validation score (nb of misclassifications)")
-pl.plot(range(1, len(rfecv.grid_scores_) + 1), rfecv.grid_scores_)
-pl.show()
+import matplotlib.pyplot as plt
+plt.figure()
+plt.xlabel("Number of features selected")
+plt.ylabel("Cross validation score (nb of correct classifications)")
+plt.plot(range(1, len(rfecv.grid_scores_) + 1), rfecv.grid_scores_)
+plt.show()
