@@ -15,7 +15,7 @@ See http://scikit-learn.org for complete documentation.
 import sys
 import re
 import warnings
-__version__ = '0.15.1'
+__version__ = '0.15.2'
 
 # Make sure that DeprecationWarning within this package always gets printed
 warnings.filterwarnings('always', category=DeprecationWarning,
@@ -36,6 +36,7 @@ if __SKLEARN_SETUP__:
 else:
     from . import __check_build
     from .base import clone
+    __check_build  # avoid flakes unused variable error
 
     def test(*args, **kwargs):
         import warnings
@@ -60,14 +61,17 @@ the tests and will be removed in release 0.16.
     # "test" as a test function
     test.__test__ = False
 
-    __all__ = ['cross_validation', 'cluster', 'covariance',
-               'datasets', 'decomposition', 'feature_extraction',
-               'feature_selection', 'semi_supervised',
-               'gaussian_process', 'grid_search', 'hmm', 'lda', 'linear_model',
-               'metrics', 'mixture', 'naive_bayes', 'neighbors', 'pipeline',
-               'preprocessing', 'qda', 'svm', 'clone',
-               'cross_decomposition',
-               'isotonic', 'pls']
+    __all__ = ['cluster', 'covariance', 'cross_decomposition',
+               'cross_validation', 'datasets', 'decomposition', 'dummy',
+               'ensemble', 'externals', 'feature_extraction',
+               'feature_selection', 'gaussian_process', 'grid_search', 'hmm',
+               'isotonic', 'kernel_approximation', 'lda', 'learning_curve',
+               'linear_model', 'manifold', 'metrics', 'mixture', 'multiclass',
+               'naive_bayes', 'neighbors', 'neural_network', 'pipeline', 'pls',
+               'preprocessing', 'qda', 'random_projection', 'semi_supervised',
+               'svm', 'tree',
+               # Non-modules:
+               'clone']
 
 
 def setup_module(module):
