@@ -1,4 +1,4 @@
 from .spectral import SpectralCoclustering, SpectralBiclustering
 
 __all__ = ['SpectralCoclustering',
-           'SpectralBiclustering',]
+           'SpectralBiclustering']
