@@ -18,7 +18,7 @@ import scipy.sparse as sp
 
 from ..base import BaseEstimator, ClusterMixin, TransformerMixin
 from ..metrics.pairwise import euclidean_distances
-from ..utils.extmath import row_norms
+from ..utils.extmath import row_norms, squared_norm
 from ..utils.sparsefuncs_fast import assign_rows_csr
 from ..utils.sparsefuncs import mean_variance_axis0
 from ..utils.fixes import astype
@@ -237,8 +237,7 @@ def k_means(X, n_clusters, init='k-means++', precompute_distances=True,
     if not sp.issparse(X) or hasattr(init, '__array__'):
         X_mean = X.mean(axis=0)
     if not sp.issparse(X):
-        if copy_x:
-            X = X.copy()
+        # The copy was already done above
         X -= X_mean
 
     if hasattr(init, '__array__'):
@@ -391,7 +390,7 @@ def _kmeans_single(X, n_clusters, x_squared_norms, max_iter=300,
             best_centers = centers.copy()
             best_inertia = inertia
 
-        if np.sum((centers_old - centers) ** 2) <= tol:
+        if squared_norm(centers_old - centers) <= tol:
             if verbose:
                 print("Converged at iteration %d" % i)
             break
@@ -1165,7 +1164,8 @@ class MiniBatchKMeans(KMeans):
             # disabled
             old_center_buffer = np.zeros(0, np.double)
 
-        distances = np.zeros(self.batch_size, dtype=np.float64)
+        distances = np.zeros(min(self.batch_size, X.shape[0]),
+                             dtype=np.float64)
         n_batches = int(np.ceil(float(n_samples) / self.batch_size))
         n_iter = int(self.max_iter * n_batches)
 
