@@ -30,7 +30,7 @@ import logging
 import numpy as np
 
 try:
-    import urllib.request as urllib #for backwards compatibility 
+    import urllib.request as urllib #for backwards compatibility
 except ImportError:
     import urllib
 
@@ -260,6 +260,25 @@ def fetch_lfw_people(data_home=None, funneled=True, resize=0.5,
     download_if_missing: optional, True by default
         If False, raise a IOError if the data is not locally available
         instead of trying to download the data from the source site.
+
+    Returns
+    -------
+    dataset : dict-like object with the following attributes:
+
+    dataset.data : numpy array of shape (13233, 2914)
+        Each row corresponds to a ravelled face image of original size 62 x 47
+        pixels.
+
+    dataset.images : numpy array of shape (13233, 62, 47)
+        Each row is a face image corresponding to one of the 5749 people in
+        the dataset.
+
+    dataset.target : numpy array of shape (13233,)
+        Labels associated to each face image. Those labels range from 0-5748
+        and correspond to the person IDs.
+
+    dataset.DESCR : string
+        Description of the Labeled Faces in the Wild (LFW) dataset.
     """
     lfw_home, data_folder_path = check_fetch_lfw(
         data_home=data_home, funneled=funneled,
@@ -402,6 +421,26 @@ def fetch_lfw_pairs(subset='train', data_home=None, funneled=True, resize=0.5,
     download_if_missing: optional, True by default
         If False, raise a IOError if the data is not locally available
         instead of trying to download the data from the source site.
+
+    Returns
+    -------
+    The data is returned as a Bunch object with the following attributes:
+
+    data : numpy array of shape (2200, 5828)
+        Each row corresponds to 2 ravel'd face images of original size 62 x 67
+        pixels.
+
+    pairs : numpy array of shape (2200, 2, 62, 67)
+        Each row has 2 face images corresponding to same or different person
+        from the dataset containing 5749 people.
+
+    target : numpy array of shape (13233,)
+        Labels associated to each pair of images. The two label values being
+        different persons or the same person.
+
+    DESCR : string
+        Description of the Labeled Faces in the Wild (LFW) dataset.
+
     """
     lfw_home, data_folder_path = check_fetch_lfw(
         data_home=data_home, funneled=funneled,
