@@ -72,6 +72,22 @@ def fetch_olivetti_faces(data_home=None, shuffle=False, random_state=0,
         The seed or the random number generator used to shuffle the
         data.
 
+    Returns
+    -------
+    An object with the following attributes:
+    
+    data : numpy array of shape (400, 4096)
+        Each row corresponds to a ravelled face image of original size 64 x 64 pixels.
+
+    images : numpy array of shape (400, 64, 64)
+        Each row is a face image corresponding to one of the 40 subjects of the dataset.
+
+    target : numpy array of shape (400, )
+        Labels associated to each face image. Those labels are ranging from 0-39 and correspond to the Subject IDs.
+
+    DESCR : string
+        Description of the modified Olivetti Faces Dataset.
+ 
     Notes
     ------
 
