@@ -4,9 +4,10 @@ from io import BytesIO
 import numpy as np
 import os
 import shutil
-import tempfile
+from tempfile import NamedTemporaryFile
 
 from sklearn.externals.six import b
+
 from sklearn.utils.testing import assert_equal
 from sklearn.utils.testing import assert_array_equal
 from sklearn.utils.testing import assert_array_almost_equal
@@ -14,8 +15,6 @@ from sklearn.utils.testing import assert_raises
 from sklearn.utils.testing import raises
 from sklearn.utils.testing import assert_in
 
-from sklearn.externals.six import b
-
 import sklearn
 from sklearn.datasets import (load_svmlight_file, load_svmlight_files,
                               dump_svmlight_file)
@@ -92,12 +91,12 @@ def test_load_svmlight_files():
 
 
 def test_load_svmlight_file_n_features():
-    X, y = load_svmlight_file(datafile, n_features=20)
+    X, y = load_svmlight_file(datafile, n_features=22)
 
     # test X'shape
     assert_equal(X.indptr.shape[0], 7)
     assert_equal(X.shape[0], 6)
-    assert_equal(X.shape[1], 20)
+    assert_equal(X.shape[1], 22)
 
     # test X's non-zero values
     for i, j, val in ((0, 2, 2.5), (0, 10, -5.2),
@@ -105,27 +104,28 @@ def test_load_svmlight_file_n_features():
 
         assert_equal(X[i, j], val)
 
+    # 21 features in file
+    assert_raises(ValueError, load_svmlight_file, datafile, n_features=20)
+
 
 def test_load_compressed():
     X, y = load_svmlight_file(datafile)
 
-    try:
-        tempdir = tempfile.mkdtemp(prefix="sklearn-test")
+    with NamedTemporaryFile(prefix="sklearn-test", suffix=".gz") as tmp:
+        tmp.close()  # necessary under windows
+        with open(datafile, "rb") as f:
+            shutil.copyfileobj(f, gzip.open(tmp.name, "wb"))
+        Xgz, ygz = load_svmlight_file(tmp.name)
+    assert_array_equal(X.toarray(), Xgz.toarray())
+    assert_array_equal(y, ygz)
 
-        tmpgz = os.path.join(tempdir, "datafile.gz")
-        shutil.copyfileobj(open(datafile, "rb"), gzip.open(tmpgz, "wb"))
-        Xgz, ygz = load_svmlight_file(tmpgz)
-        assert_array_equal(X.toarray(), Xgz.toarray())
-        assert_array_equal(y, ygz)
-
-        tmpbz = os.path.join(tempdir, "datafile.bz2")
-        shutil.copyfileobj(open(datafile, "rb"), BZ2File(tmpbz, "wb"))
-        Xbz, ybz = load_svmlight_file(tmpgz)
-        assert_array_equal(X.toarray(), Xbz.toarray())
-        assert_array_equal(y, ybz)
-    except:
-        shutil.rmtree(tempdir)
-        raise
+    with NamedTemporaryFile(prefix="sklearn-test", suffix=".bz2") as tmp:
+        tmp.close()  # necessary under windows
+        with open(datafile, "rb") as f:
+            shutil.copyfileobj(f, BZ2File(tmp.name, "wb"))
+        Xbz, ybz = load_svmlight_file(tmp.name)
+    assert_array_equal(X.toarray(), Xbz.toarray())
+    assert_array_equal(y, ybz)
 
 
 @raises(ValueError)
@@ -167,13 +167,13 @@ def test_load_with_qid():
     7 qid:2 1:0.87 2:0.12""")
     X, y = load_svmlight_file(BytesIO(data), query_id=False)
     assert_array_equal(y, [3, 2, 7])
-    assert_array_equal(X.todense(), [[.53, .12], [.13, .1], [.87, .12]])
+    assert_array_equal(X.toarray(), [[.53, .12], [.13, .1], [.87, .12]])
     res1 = load_svmlight_files([BytesIO(data)], query_id=True)
     res2 = load_svmlight_file(BytesIO(data), query_id=True)
     for X, y, qid in (res1, res2):
         assert_array_equal(y, [3, 2, 7])
         assert_array_equal(qid, [1, 1, 2])
-        assert_array_equal(X.todense(), [[.53, .12], [.13, .1], [.87, .12]])
+        assert_array_equal(X.toarray(), [[.53, .12], [.13, .1], [.87, .12]])
 
 
 @raises(ValueError)
