@@ -1,5 +1,3 @@
-import warnings
-
 import numpy as np
 from scipy.sparse import csr_matrix
 
@@ -7,7 +5,9 @@ from sklearn.utils.testing import assert_almost_equal
 from sklearn.utils.testing import assert_array_almost_equal
 from sklearn.utils.testing import assert_true
 from sklearn.utils.testing import assert_equal
-from sklearn.utils.testing import assert_less, assert_greater
+from sklearn.utils.testing import assert_greater
+from sklearn.utils.testing import assert_raises
+from sklearn.utils.testing import assert_warns
 
 from sklearn import datasets
 from sklearn.decomposition import PCA
@@ -38,6 +38,16 @@ def test_pca():
 
     assert_array_almost_equal(X_r, X_r2)
 
+    # Test get_covariance and get_precision with n_components == n_features
+    # with n_components < n_features and with n_components == 0
+    for n_components in [0, 2, X.shape[1]]:
+        pca.n_components = n_components
+        pca.fit(X)
+        cov = pca.get_covariance()
+        precision = pca.get_precision()
+        assert_array_almost_equal(np.dot(cov, precision),
+                                  np.eye(X.shape[1]), 12)
+
 
 def test_whitening():
     """Check that PCA output has unit-variance"""
@@ -85,6 +95,39 @@ def test_whitening():
         # we always center, so no test for non-centering.
 
 
+def test_explained_variance():
+    """Check that PCA output has unit-variance"""
+    rng = np.random.RandomState(0)
+    n_samples = 100
+    n_features = 80
+
+    X = rng.randn(n_samples, n_features)
+
+    pca = PCA(n_components=2).fit(X)
+    rpca = RandomizedPCA(n_components=2, random_state=42).fit(X)
+    assert_array_almost_equal(pca.explained_variance_,
+                              rpca.explained_variance_, 1)
+    assert_array_almost_equal(pca.explained_variance_ratio_,
+                              rpca.explained_variance_ratio_, 3)
+
+    # compare to empirical variances
+    X_pca = pca.transform(X)
+    assert_array_almost_equal(pca.explained_variance_,
+                              np.var(X_pca, axis=0))
+
+    X_rpca = rpca.transform(X)
+    assert_array_almost_equal(rpca.explained_variance_,
+                              np.var(X_rpca, axis=0))
+
+    # Compare with RandomizedPCA using sparse data
+    X = csr_matrix(X)
+    rpca = assert_warns(DeprecationWarning, rpca.fit, X)
+    assert_array_almost_equal(pca.explained_variance_,
+                              rpca.explained_variance_, 1)
+    assert_array_almost_equal(pca.explained_variance_ratio_,
+                              rpca.explained_variance_ratio_, 3)
+
+
 def test_pca_check_projection():
     """Test that the projection of data is correct"""
     rng = np.random.RandomState(0)
@@ -123,6 +166,12 @@ def test_pca_inverse():
     assert_almost_equal(relative_max_delta, 0.11, decimal=2)
 
 
+def test_pca_validation():
+    X = [[0, 1], [1, 0]]
+    for n_components in [-1, 3]:
+        assert_raises(ValueError, PCA(n_components).fit, X)
+
+
 def test_randomized_pca_check_projection():
     """Test that the projection by RandomizedPCA on dense data is correct"""
     rng = np.random.RandomState(0)
@@ -181,11 +230,8 @@ def test_sparse_randomized_pca_check_projection():
     Xt = 0.1 * rng.randn(1, p) + np.array([3, 4, 5])
     Xt = csr_matrix(Xt)
 
-    with warnings.catch_warnings(record=True) as w:
-        warnings.simplefilter('always', DeprecationWarning)
-        Yt = RandomizedPCA(n_components=2, random_state=0).fit(X).transform(Xt)
-        assert_equal(len(w), 1)
-        assert_equal(w[0].category, DeprecationWarning)
+    pca = RandomizedPCA(n_components=2, random_state=0)
+    Yt = assert_warns(DeprecationWarning, pca.fit, X).transform(Xt)
 
     Yt /= np.sqrt((Yt ** 2).sum())
 
@@ -204,29 +250,20 @@ def test_sparse_randomized_pca_inverse():
 
     # same check that we can find the original data from the transformed signal
     # (since the data is almost of rank n_components)
-    with warnings.catch_warnings(record=True) as w:
-        warnings.simplefilter('always', DeprecationWarning)
-        pca = RandomizedPCA(n_components=2, random_state=0).fit(X)
-        assert_equal(len(w), 1)
-        assert_equal(w[0].category, DeprecationWarning)
-
+    pca = RandomizedPCA(n_components=2, random_state=0)
+    assert_warns(DeprecationWarning, pca.fit, X)
     Y = pca.transform(X)
 
     Y_inverse = pca.inverse_transform(Y)
-    assert_almost_equal(X.todense(), Y_inverse, decimal=2)
+    assert_almost_equal(X.toarray(), Y_inverse, decimal=2)
 
     # same as above with whitening (approximate reconstruction)
-    with warnings.catch_warnings(record=True) as w:
-        warnings.simplefilter('always', DeprecationWarning)
-        pca = RandomizedPCA(n_components=2, whiten=True,
-                            random_state=0).fit(X)
-        assert_equal(len(w), 1)
-        assert_equal(w[0].category, DeprecationWarning)
-
+    pca = assert_warns(DeprecationWarning, RandomizedPCA(n_components=2,
+                       whiten=True, random_state=0).fit, X)
     Y = pca.transform(X)
     Y_inverse = pca.inverse_transform(Y)
-    relative_max_delta = (np.abs(X.todense() - Y_inverse)
-                          / np.abs(X).mean()).max()
+    relative_max_delta = (np.abs(X.toarray() - Y_inverse)
+                          / np.abs(X.toarray()).mean()).max()
     # XXX: this does not seam to work as expected:
     assert_almost_equal(relative_max_delta, 0.91, decimal=2)
 
@@ -238,7 +275,8 @@ def test_pca_dim():
     X = rng.randn(n, p) * .1
     X[:10] += np.array([3, 4, 5, 1, 2])
     pca = PCA(n_components='mle').fit(X)
-    assert_equal(pca.n_components, 1)
+    assert_equal(pca.n_components, 'mle')
+    assert_equal(pca.n_components_, 1)
 
 
 def test_infer_dim_1():
@@ -295,17 +333,67 @@ def test_infer_dim_by_explained_variance():
     X = iris.data
     pca = PCA(n_components=0.95)
     pca.fit(X)
-    assert_equal(pca.n_components, 2)
+    assert_equal(pca.n_components, 0.95)
+    assert_equal(pca.n_components_, 2)
 
     pca = PCA(n_components=0.01)
     pca.fit(X)
-    assert_equal(pca.n_components, 1)
+    assert_equal(pca.n_components, 0.01)
+    assert_equal(pca.n_components_, 1)
 
     rng = np.random.RandomState(0)
     # more features than samples
     X = rng.rand(5, 20)
     pca = PCA(n_components=.5).fit(X)
-    assert_equal(pca.n_components, 2)
+    assert_equal(pca.n_components, 0.5)
+    assert_equal(pca.n_components_, 2)
+
+
+def test_pca_score():
+    """Test that probabilistic PCA scoring yields a reasonable score"""
+    n, p = 1000, 3
+    rng = np.random.RandomState(0)
+    X = rng.randn(n, p) * .1 + np.array([3, 4, 5])
+    pca = PCA(n_components=2)
+    pca.fit(X)
+    ll1 = pca.score(X)
+    h = -0.5 * np.log(2 * np.pi * np.exp(1) * 0.1 ** 2) * p
+    np.testing.assert_almost_equal(ll1 / h, 1, 0)
+
+
+def test_pca_score2():
+    """Test that probabilistic PCA correctly separated different datasets"""
+    n, p = 100, 3
+    rng = np.random.RandomState(0)
+    X = rng.randn(n, p) * .1 + np.array([3, 4, 5])
+    pca = PCA(n_components=2)
+    pca.fit(X)
+    ll1 = pca.score(X)
+    ll2 = pca.score(rng.randn(n, p) * .2 + np.array([3, 4, 5]))
+    assert_greater(ll1, ll2)
+
+    # Test that it gives the same scores if whiten=True
+    pca = PCA(n_components=2, whiten=True)
+    pca.fit(X)
+    ll2 = pca.score(X)
+    assert_almost_equal(ll1, ll2)
+
+
+def test_pca_score3():
+    """Check that probabilistic PCA selects the right model"""
+    n, p = 200, 3
+    rng = np.random.RandomState(0)
+    Xl = (rng.randn(n, p) + rng.randn(n, 1) * np.array([3, 4, 5])
+          + np.array([1, 0, 7]))
+    Xt = (rng.randn(n, p) + rng.randn(n, 1) * np.array([3, 4, 5])
+          + np.array([1, 0, 7]))
+    ll = np.zeros(p)
+    for k in range(p):
+        pca = PCA(n_components=k)
+        pca.fit(Xl)
+        ll[k] = pca.score(Xt)
+
+    assert_true(ll.argmax() == 1)
 
 
 def test_probabilistic_pca_1():
@@ -313,7 +401,8 @@ def test_probabilistic_pca_1():
     n, p = 1000, 3
     rng = np.random.RandomState(0)
     X = rng.randn(n, p) * .1 + np.array([3, 4, 5])
-    ppca = ProbabilisticPCA(n_components=2)
+
+    ppca = assert_warns(DeprecationWarning, ProbabilisticPCA, n_components=2)
     ppca.fit(X)
     ll1 = ppca.score(X)
     h = -0.5 * np.log(2 * np.pi * np.exp(1) * 0.1 ** 2) * p
@@ -325,7 +414,7 @@ def test_probabilistic_pca_2():
     n, p = 100, 3
     rng = np.random.RandomState(0)
     X = rng.randn(n, p) * .1 + np.array([3, 4, 5])
-    ppca = ProbabilisticPCA(n_components=2)
+    ppca = assert_warns(DeprecationWarning, ProbabilisticPCA, n_components=2)
     ppca.fit(X)
     ll1 = ppca.score(X)
     ll2 = ppca.score(rng.randn(n, p) * .2 + np.array([3, 4, 5]))
@@ -333,22 +422,22 @@ def test_probabilistic_pca_2():
 
 
 def test_probabilistic_pca_3():
-    """The homoscedastic model should work slightly worth
+    """The homoscedastic model should work slightly worse
     than the heteroscedastic one in over-fitting condition
     """
     n, p = 100, 3
     rng = np.random.RandomState(0)
     X = rng.randn(n, p) * .1 + np.array([3, 4, 5])
-    ppca = ProbabilisticPCA(n_components=2)
-    ppca.fit(X)
-    ll1 = ppca.score(X)
-    ppca.fit(X, homoscedastic=False)
-    ll2 = ppca.score(X)
-    assert_less(ll1.mean(), ll2.mean())
+    ppca = assert_warns(DeprecationWarning, ProbabilisticPCA, n_components=2)
+    ppca.fit(X).score(X)
+    ppca.fit(X, homoscedastic=False).score(X)
+    # XXX : Don't test as homoscedastic=False is buggy
+    # Comment to be removed with ProbabilisticPCA is removed
 
 
 def test_probabilistic_pca_4():
     """Check that ppca select the right model"""
+
     n, p = 200, 3
     rng = np.random.RandomState(0)
     Xl = (rng.randn(n, p) + rng.randn(n, 1) * np.array([3, 4, 5])
@@ -357,13 +446,26 @@ def test_probabilistic_pca_4():
           + np.array([1, 0, 7]))
     ll = np.zeros(p)
     for k in range(p):
-        ppca = ProbabilisticPCA(n_components=k)
+        ppca = assert_warns(DeprecationWarning, ProbabilisticPCA,
+                            n_components=k)
         ppca.fit(Xl)
         ll[k] = ppca.score(Xt).mean()
 
     assert_true(ll.argmax() == 1)
 
 
+def test_probabilistic_pca_vs_pca():
+    """Test that PCA matches ProbabilisticPCA with homoscedastic=True
+    """
+    n, p = 100, 3
+    rng = np.random.RandomState(0)
+    X = rng.randn(n, p) * .1 + np.array([3, 4, 5])
+    pca = PCA(n_components=2).fit(X)
+    ppca = assert_warns(DeprecationWarning, ProbabilisticPCA,
+                        n_components=2).fit(X)
+    assert_array_almost_equal(pca.score_samples(X), ppca.score(X))
+
+
 if __name__ == '__main__':
     import nose
     nose.run(argv=['', __file__])
