@@ -8,6 +8,7 @@ Testing for the base module (sklearn.ensemble.base).
 from numpy.testing import assert_equal
 from nose.tools import assert_true
 
+from sklearn.utils.testing import assert_raise_message
 from sklearn.datasets import load_iris
 from sklearn.ensemble import BaggingClassifier
 from sklearn.linear_model import Perceptron
@@ -30,3 +31,13 @@ def test_base():
     assert_equal(3, len(ensemble.estimators_))
 
     assert_true(isinstance(ensemble[0], Perceptron))
+
+
+def test_base_zero_n_estimators():
+    """Check that instantiating a BaseEnsemble with n_estimators<=0 raises
+    a ValueError."""
+    ensemble = BaggingClassifier(base_estimator=Perceptron(), n_estimators=0)
+    iris = load_iris()
+    assert_raise_message(ValueError,
+                         "n_estimators must be greater than zero, got 0.",
+                         ensemble.fit, iris.data, iris.target)
