@@ -226,9 +226,10 @@ class LDA(BaseEstimator, ClassifierMixin, TransformerMixin):
         """
         X = array2d(X)
         # center and scale data
-        X = np.dot(X - self.xbar_, self.scalings_)
-        n_comp = X.shape[1] if self.n_components is None else self.n_components
-        return np.dot(X, self.coef_[:n_comp].T)
+        X_new = np.dot(X - self.xbar_, self.scalings_)
+        n_components = X.shape[1] if self.n_components is None \
+            else self.n_components
+        return X_new[:, :n_components]
 
     def predict(self, X):
         """
