@@ -6,6 +6,7 @@
 # License: BSD 3 clause
 
 import warnings
+from distutils.version import LooseVersion
 
 import numpy as np
 from scipy import linalg
@@ -13,10 +14,15 @@ from scipy.linalg.lapack import get_lapack_funcs
 
 from .base import LinearModel, _pre_fit
 from ..base import RegressorMixin
-from ..utils import array2d, as_float_array
-from ..cross_validation import check_cv
+from ..utils import array2d, as_float_array, check_arrays
+from ..cross_validation import _check_cv as check_cv
 from ..externals.joblib import Parallel, delayed
-from ..utils.arrayfuncs import solve_triangular
+
+import scipy
+solve_triangular_args = {}
+if LooseVersion(scipy.__version__) >= LooseVersion('0.12'):
+    solve_triangular_args = {'check_finite': False}
+
 
 premature = """ Orthogonal matching pursuit ended prematurely due to linear
 dependence in the dictionary. The requested precision might not have been met.
@@ -95,7 +101,11 @@ def _cholesky_omp(X, y, n_nonzero_coefs, tol=None, copy_X=True,
         if n_active > 0:
             # Updates the Cholesky decomposition of X' X
             L[n_active, :n_active] = np.dot(X[:, :n_active].T, X[:, lam])
-            solve_triangular(L[:n_active, :n_active], L[n_active, :n_active])
+            linalg.solve_triangular(L[:n_active, :n_active],
+                                    L[n_active, :n_active],
+                                    trans=0, lower=1,
+                                    overwrite_b=True,
+                                    **solve_triangular_args)
             v = nrm2(L[n_active, :n_active]) ** 2
             if 1 - v <= min_float:  # selected atoms are dependent
                 warnings.warn(premature, RuntimeWarning, stacklevel=2)
@@ -199,14 +209,18 @@ def _gram_omp(Gram, Xy, n_nonzero_coefs, tol_0=None, tol=None,
         lam = np.argmax(np.abs(alpha))
         if lam < n_active or alpha[lam] ** 2 < min_float:
             # selected same atom twice, or inner product too small
-            warnings.warn(premature, RuntimeWarning, stacklevel=2)
+            warnings.warn(premature, RuntimeWarning, stacklevel=3)
             break
         if n_active > 0:
             L[n_active, :n_active] = Gram[lam, :n_active]
-            solve_triangular(L[:n_active, :n_active], L[n_active, :n_active])
+            linalg.solve_triangular(L[:n_active, :n_active],
+                                    L[n_active, :n_active],
+                                    trans=0, lower=1,
+                                    overwrite_b=True,
+                                    **solve_triangular_args)
             v = nrm2(L[n_active, :n_active]) ** 2
             if 1 - v <= min_float:  # selected atoms are dependent
-                warnings.warn(premature, RuntimeWarning, stacklevel=2)
+                warnings.warn(premature, RuntimeWarning, stacklevel=3)
                 break
             L[n_active, n_active] = np.sqrt(1 - v)
         Gram[n_active], Gram[lam] = swap(Gram[n_active], Gram[lam])
@@ -225,7 +239,7 @@ def _gram_omp(Gram, Xy, n_nonzero_coefs, tol_0=None, tol=None,
             tol_curr += delta
             delta = np.inner(gamma, beta[:n_active])
             tol_curr -= delta
-            if tol_curr <= tol:
+            if abs(tol_curr) <= tol:
                 break
         elif n_active == max_features:
             break
@@ -524,7 +538,7 @@ class OrthogonalMatchingPursuit(LinearModel, RegressorMixin):
     Attributes
     ----------
     `coef_` : array, shape (n_features,) or (n_features, n_targets)
-        parameter vector (w in the fomulation formula)
+        parameter vector (w in the formula)
 
     `intercept_` : float or array, shape (n_targets,)
         independent term in decision function.
@@ -790,15 +804,15 @@ class OrthogonalMatchingPursuitCV(LinearModel, RegressorMixin):
 
     Attributes
     ----------
-    `n_nonzero_coefs_` : int
-        Estimated number of non-zero coefficients giving the best mean
-        squared error over the cross-validation folds.
+    `intercept_` : float or array, shape (n_targets,)
+        Independent term in decision function.
 
     `coef_` : array, shape (n_features,) or (n_features, n_targets)
-        parameter vector (w in the problem formulation).
+        Parameter vector (w in the problem formulation).
 
-    `intercept_` : float or array, shape (n_targets,)
-        independent term in decision function.
+    `n_nonzero_coefs_` : int
+        Estimated number of non-zero coefficients giving the best mean squared
+        error over the cross-validation folds.
 
     See also
     --------
@@ -840,6 +854,7 @@ class OrthogonalMatchingPursuitCV(LinearModel, RegressorMixin):
             returns an instance of self.
         """
         X = array2d(X)
+        X, y = check_arrays(X, y)
         cv = check_cv(self.cv, X, y, classifier=False)
         max_iter = (min(max(int(0.1 * X.shape[1]), 5), X.shape[1])
                     if not self.max_iter
