@@ -19,6 +19,8 @@ def silhouette_score(X, labels, metric='euclidean', sample_size=None,
     sample.  The Silhouette Coefficient for a sample is ``(b - a) / max(a,
     b)``.  To clarify, ``b`` is the distance between a sample and the nearest
     cluster that the sample is not a part of.
+    Note that Silhouette Coefficent is only defined if number of labels
+    is 2 <= n_labels <= n_samples - 1.
 
     This function returns the mean Silhouette Coefficient over all samples.
     To obtain the values for each sample, use :func:`silhouette_samples`.
@@ -74,6 +76,13 @@ def silhouette_score(X, labels, metric='euclidean', sample_size=None,
            <http://en.wikipedia.org/wiki/Silhouette_(clustering)>`_
 
     """
+    n_labels = len(np.unique(labels))
+    n_samples = X.shape[0]
+    if not 2 <= n_labels <= n_samples-1:
+        raise ValueError("Number of labels is %d "
+                         "but should be more than 2"
+                         "and less than n_samples - 1" % n_labels)
+
     if sample_size is not None:
         random_state = check_random_state(random_state)
         indices = random_state.permutation(X.shape[0])[:sample_size]
@@ -97,6 +106,8 @@ def silhouette_samples(X, labels, metric='euclidean', **kwds):
     distance (``a``) and the mean nearest-cluster distance (``b``) for each
     sample.  The Silhouette Coefficient for a sample is ``(b - a) / max(a,
     b)``.
+    Note that Silhouette Coefficent is only defined if number of labels
+    is 2 <= n_labels <= n_samples - 1.
 
     This function returns the Silhouette Coefficient for each sample.
 
