@@ -63,7 +63,7 @@ class KNeighborsClassifier(NeighborsBase, KNeighborsMixin,
         required to store the tree.  The optimal value depends on the
         nature of the problem.
 
-    metric : string or DistanceMetric object (default='minkowski')
+    metric : string or DistanceMetric object (default = 'minkowski')
         the distance metric to use for the tree.  The default metric is
         minkowski, and with p=2 is equivalent to the standard Euclidean
         metric. See the documentation of the DistanceMetric class for a
@@ -74,9 +74,8 @@ class KNeighborsClassifier(NeighborsBase, KNeighborsMixin,
         equivalent to using manhattan_distance (l1), and euclidean_distance
         (l2) for p = 2. For arbitrary p, minkowski_distance (l_p) is used.
 
-    **kwargs :
-        additional keyword arguments are passed to the distance function as
-        additional arguments.
+    metric_params: dict, optional (default = None)
+        additional keyword arguments for the metric function.
 
     Examples
     --------
@@ -115,7 +114,7 @@ class KNeighborsClassifier(NeighborsBase, KNeighborsMixin,
 
     def __init__(self, n_neighbors=5,
                  weights='uniform', algorithm='auto', leaf_size=30,
-                 p=2, metric='minkowski', **kwargs):
+                 p=2, metric='minkowski', metric_params=None, **kwargs):
         if kwargs:
             if 'warn_on_equidistant' in kwargs:
                 kwargs.pop('warn_on_equidistant')
@@ -123,9 +122,11 @@ class KNeighborsClassifier(NeighborsBase, KNeighborsMixin,
                               "deprecated and will be removed in 0.16.",
                               DeprecationWarning,
                               stacklevel=2)
+
         self._init_params(n_neighbors=n_neighbors,
                           algorithm=algorithm,
-                          leaf_size=leaf_size, metric=metric, p=p, **kwargs)
+                          leaf_size=leaf_size, metric=metric, p=p,
+                          metric_params=metric_params, **kwargs)
         self.weights = _check_weights(weights)
 
     def predict(self, X):
@@ -286,9 +287,8 @@ class RadiusNeighborsClassifier(NeighborsBase, RadiusNeighborsMixin,
         neighbors on given radius).
         If set to None, ValueError is raised, when outlier is detected.
 
-    **kwargs :
-        additional keyword arguments are passed to the distance function as
-        additional arguments.
+    metric_params: dict, optional (default = None)
+        additional keyword arguments for the metric function.
 
     Examples
     --------
@@ -318,11 +318,12 @@ class RadiusNeighborsClassifier(NeighborsBase, RadiusNeighborsMixin,
 
     def __init__(self, radius=1.0, weights='uniform',
                  algorithm='auto', leaf_size=30, p=2, metric='minkowski',
-                 outlier_label=None, **kwargs):
+                 outlier_label=None, metric_params=None, **kwargs):
         self._init_params(radius=radius,
                           algorithm=algorithm,
                           leaf_size=leaf_size,
-                          metric=metric, p=p, **kwargs)
+                          metric=metric, p=p, metric_params=metric_params,
+                          **kwargs)
         self.weights = _check_weights(weights)
         self.outlier_label = outlier_label
 
