@@ -43,6 +43,9 @@ class NearestNeighbors(NeighborsBase, KNeighborsMixin,
         equivalent to using manhattan_distance (l1), and euclidean_distance
         (l2) for p = 2. For arbitrary p, minkowski_distance (l_p) is used.
 
+    metric_params: dict, optional (default = None)
+        additional keyword arguments for the metric function.
+
     Examples
     --------
       >>> from sklearn.neighbors import NearestNeighbors
@@ -76,8 +79,10 @@ class NearestNeighbors(NeighborsBase, KNeighborsMixin,
     """
 
     def __init__(self, n_neighbors=5, radius=1.0,
-                 algorithm='auto', leaf_size=30, metric='minkowski', **kwargs):
+                 algorithm='auto', leaf_size=30, metric='minkowski',
+                 p=2, metric_params=None, **kwargs):
         self._init_params(n_neighbors=n_neighbors,
                           radius=radius,
                           algorithm=algorithm,
-                          leaf_size=leaf_size, metric=metric, **kwargs)
+                          leaf_size=leaf_size, metric=metric, p=p,
+                          metric_params=metric_params, **kwargs)
