@@ -3,11 +3,10 @@ from io import BytesIO
 import numpy as np
 import scipy.sparse
 
-import warnings
-
 from sklearn.datasets import load_digits
 from sklearn.cross_validation import cross_val_score
 
+from sklearn.externals.six.moves import zip
 from sklearn.utils.testing import assert_almost_equal
 from sklearn.utils.testing import assert_array_equal
 from sklearn.utils.testing import assert_array_almost_equal
@@ -253,27 +252,6 @@ def test_discretenb_provide_prior():
                       classes=[0, 1, 1])
 
 
-def test_deprecated_fit_param():
-    warnings.simplefilter("always", DeprecationWarning)
-    try:
-        for cls in [BernoulliNB, MultinomialNB]:
-            clf = cls()
-            with warnings.catch_warnings(record=True) as w:
-                clf.fit([[0], [1], [2]], [0, 1, 1], class_prior=[0.5, 0.5])
-
-            # Passing class_prior as a fit param should raise a deprecation
-            # warning
-            assert_equal(len(w), 1)
-            assert_equal(w[0].category, DeprecationWarning)
-
-            with warnings.catch_warnings(record=True):
-                # Inconsistent number of classes with prior
-                assert_raises(ValueError, clf.fit, [[0], [1], [2]], [0, 1, 2],
-                              class_prior=[0.5, 0.5])
-    finally:
-        warnings.filters.pop(0)
-
-
 def test_sample_weight_multiclass():
     for cls in [BernoulliNB, MultinomialNB]:
         # check shape consistency for number of samples at fit time
@@ -329,8 +307,8 @@ def test_coef_intercept_shape():
 
 def test_check_accuracy_on_digits():
     # Non regression test to make sure that any further refactoring / optim
-    # of the NB models do not harm the performance on a non linearly separable
-    # dataset
+    # of the NB models do not harm the performance on a slightly non-linearly
+    # separable dataset
     digits = load_digits()
     X, y = digits.data, digits.target
     binary_3v8 = np.logical_or(digits.target == 3, digits.target == 8)
@@ -338,21 +316,21 @@ def test_check_accuracy_on_digits():
 
     # Multinomial NB
     scores = cross_val_score(MultinomialNB(alpha=10), X, y, cv=10)
-    assert_greater(scores.mean(), 0.90)
+    assert_greater(scores.mean(), 0.86)
 
     scores = cross_val_score(MultinomialNB(alpha=10), X_3v8, y_3v8, cv=10)
-    assert_greater(scores.mean(), 0.95)
+    assert_greater(scores.mean(), 0.94)
 
     # Bernoulli NB
     scores = cross_val_score(BernoulliNB(alpha=10), X > 4, y, cv=10)
-    assert_greater(scores.mean(), 0.85)
+    assert_greater(scores.mean(), 0.83)
 
     scores = cross_val_score(BernoulliNB(alpha=10), X_3v8 > 4, y_3v8, cv=10)
-    assert_greater(scores.mean(), 0.94)
+    assert_greater(scores.mean(), 0.92)
 
     # Gaussian NB
     scores = cross_val_score(GaussianNB(), X, y, cv=10)
-    assert_greater(scores.mean(), 0.81)
+    assert_greater(scores.mean(), 0.77)
 
     scores = cross_val_score(GaussianNB(), X_3v8, y_3v8, cv=10)
     assert_greater(scores.mean(), 0.86)
