@@ -1,12 +1,11 @@
 # Authors: Andreas Mueller
+#          Manoj Kumar
 # License: BSD 3 clause
 
 import numpy as np
 
-from .fixes import bincount
 
-
-def compute_class_weight(class_weight, classes, y_ind):
+def compute_class_weight(class_weight, classes, y):
     """Estimate class weights for unbalanced datasets.
 
     Parameters
@@ -22,25 +21,30 @@ def compute_class_weight(class_weight, classes, y_ind):
         Array of the classes occurring in the data, as given by
         ``np.unique(y_org)`` with ``y_org`` the original class labels.
 
-    y_ind : array-like, shape=(n_samples,), dtype=int
-        Array of class indices per sample;
-        0 <= y_ind[i] < n_classes for i in range(n_samples).
+    y : array-like, shape (n_samples,)
+        Array of original class labels per sample;
 
     Returns
     -------
-    class_weight_vect : ndarray, shape=(n_classes,)
+    class_weight_vect : ndarray, shape (n_classes,)
         Array with class_weight_vect[i] the weight for i-th class
-        (as determined by sorting).
     """
+    # Import error caused by circular imports.
+    from ..preprocessing import LabelEncoder
+
     if class_weight is None or len(class_weight) == 0:
         # uniform class weights
         weight = np.ones(classes.shape[0], dtype=np.float64, order='C')
     elif class_weight == 'auto':
+        # Find the weight of each class as present in y.
+        le = LabelEncoder()
+        y_ind = le.fit_transform(y)
+        if not all(np.in1d(classes, le.classes_)):
+            raise ValueError("classes should have valid labels that are in y")
+
         # inversely proportional to the number of samples in the class
-        counts = bincount(y_ind, minlength=len(classes))
-        counts = np.maximum(counts, 1)
-        weight = 1. / counts
-        weight *= classes.shape[0] / np.sum(weight)
+        recip_freq = 1. / np.bincount(y_ind)
+        weight = recip_freq[le.transform(classes)] / np.mean(recip_freq)
     else:
         # user-defined dictionary
         weight = np.ones(classes.shape[0], dtype=np.float64, order='C')
